@@ -1,11 +1,18 @@
-shinyUI(fluidPage(theme = shinytheme("spacelab"),
+shinyUI(
   
+  fluidPage(
+  
+    #theme = uiOutput("shinytheme"),
+   
     shinyjs::useShinyjs(), # Set up shinyjs
-    
+     
     headerPanel("",windowTitle="compareGroups | Explore and Summarise Epidemiological Data in R"),
-
+    
+    uiOutput("shinythemesout"),
+    uiOutput("panelwidthout"),
+    
     HTML('<style type="text/css"> #inputpanel{ max-height:800px; overflow:auto; margin-right:-3%} </style>'),
-    HTML('<style type="text/css"> #outpanel {min-height:150px;} </style>'), 
+    HTML('<style type="text/css"> #outpanel {min-height:150px} </style>'), 
     HTML('<style type="text/css"> #showload { background-color: rgb(250,250,250); border: 2px solid grey;} </style>'),
     HTML('<style type="text/css"> #selevars { width: 120px;} </style>'), 
     HTML('<style type="text/css"> #discvars { width: 120px;} </style>'),
@@ -13,12 +20,22 @@ shinyUI(fluidPage(theme = shinytheme("spacelab"),
     HTML('<style type="text/css"> #varPlot { width: 120px;} </style>'),
     HTML('<style type="text/css"> #maxvalues { width: 100px;} </style>'),
     HTML('<style type="text/css"> #exampledata { width: 200px;} </style>'),
-    HTML('<style type="text/css"> #initial { height: 0px; width: 0px} </style>'),
+    #HTML('<style type="text/css"> #initial { height: 0px; width: 0px} </style>'),
     HTML('<style type="text/css"> #count { height: 0px; width: 0px} </style>'),
     HTML('<style type="text/css"> #bsModalhelpcg .modal-content { width:120%;height:120%;} </style>'),
     HTML('<style type="text/css"> #bsModalhelpcg .modal-header { background-color:rgb(68,110,155);} </style>'),
+    HTML('<style type="text/css"> #tableoptions,#infooptions,#valuessumoptions,#valuextoptions,#SNPsoptions {background-color:#D1F0F0;padding:20px;text-align:center;margin-top:-10px;margin-bottom:10px;border:1px solid black; border-radius: 8px;} </style>'),    
+    HTML('<style type="text/css"> #results {font-size:18px;font-weight:bold;font-color:red;} </style>'),        
     
-
+    
+    HTML('<button title="Settings" id="settingaction" type="button" class="btn btn-default action-button btn-sm" style="margin-bottom:5px;"><i class="fa fa-gear"></i></button>'),
+    bsModal(id="modalSettings",title="Settings",trigger="settingaction",
+      selectInput("shinythemes","Select shiny theme",choices=c("cerulean","cosmo","cyborg","darkly","flatly","journal","lumen","paper","readable","sandstone","simplex","slate","united","spacelab","superhero","yeti"),selected="spacelab"),
+      sliderInput("panelwidth","Left panel width %",0,100,30,5)
+    ),
+    
+    
+     
     fluidRow(
 
     ##################################################     
@@ -32,13 +49,13 @@ shinyUI(fluidPage(theme = shinytheme("spacelab"),
           bsCollapse(id = "collapseInput", open = c("collapseLoad"),
             
             ## load data
-            bsCollapsePanel(title="Step 1. Load data", value="collapseLoad", style = "primary",
+            bsCollapsePanel(title=HTML('<font style="font-size:18px">Step 1. Load data</font>'), value="collapseLoad", style = "primary",
               uiOutput("initial"),
               column(1,bsButton("infoLoad","",size="extra-small",style="info",icon=icon("info-circle")),offset=11),
               bsModal("infoLoadModal",HTML('<p> <strong>Step 1. Load data</strong></p>'), "infoLoad",uiOutput("helpload")),
               #radioButtons("exampledata", "", choices = c("Own data","REGICOR","PREDIMED","SNPS")),
               HTML('
-              <div id="exampledata" class="form-group shiny-input-radiogroup shiny-input-container">
+              <div id="exampledata" class="form-group shiny-input-radiogroup shiny-input-container" style="text-align:justify">
                 <label class="control-label" for="exampledata"></label>
                 <div class="shiny-options-group">
                 <div class="radio">
@@ -67,27 +84,24 @@ shinyUI(fluidPage(theme = shinytheme("spacelab"),
                 </label>
                 </div>
                 </div>
-                </div>'), 
+                </div>'
+              ), 
               conditionalPanel(
                 condition = "input.exampledata == 'Own data'",
                 fileInput("files", "", accept=c('', 'sav', 'csv', 'dat', 'txt', 'xls', 'xlsx', 'mdb')),
-                selectInput("datatype", "Data format", c('SPSS'='*.sav', 'TEXT'='*.txt','EXCEL'='*.xls','R'='*.rda'),'*.sav'),
-                bsButton("encodingaction", "Encoding", size="extra-small", style="info"),
-                radioButtons("encoding", "", c('default'='default','latin1'='latin1','utf8'='utf8'),'default',inline=TRUE),
-                uiOutput("loadoptions")
+                uiOutput("loadpanel")
               ),
-              br(),
-              actionButton("loadok","OK")
+              uiOutput("loadokui")
             ),
             
             ## vars list
-            bsCollapsePanel(title="Step 2. Select variables", value="collapseSelect", style = "primary", 
+            bsCollapsePanel(title=HTML('<font style="font-size:18px">Step 2. Select variables</font>'), value="collapseSelect", style = "primary", 
               column(1,bsButton("infoSelect","",size="extra-small",style="info",icon=icon("info-circle")),offset=11),
               bsModal("infoSelectModal",HTML('<p> <strong>Step 2. Select variables</strong></p>'), "infoSelect",uiOutput("helpselect")),
               uiOutput("selevarslist")
             ),
             ## settings
-            bsCollapsePanel(title="Step 3. Settings", value="collapseSettings", style = "primary", 
+            bsCollapsePanel(title=HTML('<font style="font-size:18px">Step 3. Settings</font>'), value="collapseSettings", style = "primary", 
               column(1,bsButton("infoSettings","",size="extra-small",style="info",icon=icon("info-circle")),offset=11),
               bsModal("infoSettingsModal",HTML('<p> <strong>Step 3. Settings</strong></p>'), "infoSettings",
                 tabsetPanel(
@@ -98,41 +112,10 @@ shinyUI(fluidPage(theme = shinytheme("spacelab"),
                   tabPanel("OR/HR", uiOutput("helpratio"))
                 )
               ),
-              conditionalPanel(
-                condition = "input.initial",
-                tabsetPanel(
-                  ## methods
-                  tabPanel("Type",
-                    uiOutput("selemethod"),
-                    uiOutput("selemethodNA")
-                  ),
-                  ## response
-                  tabPanel("Response",
-                    radioButtons("resptype", "", c("None","Group","Survival"),"None"),                 
-                    actionButton("changeresp","","Update"),
-                    uiOutput("response")
-                  ),            
-                  ## hide
-                  tabPanel("Hide",
-                    br(),
-                    wellPanel(
-                      fluidRow(
-                        column(6,uiOutput("selehidevar")),
-                        column(6,uiOutput("selehidecat"))
-                      )
-                    ),
-                    textInput('hideno', "Hide 'no' category", ''),
-                    actionButton("changehide","Update")
-                  ),
-                  ## subset
-                  tabPanel("Subset", uiOutput("selevarsubset")),
-                  ## OR/HR ratio for row-variables
-                  tabPanel("OR/HR", uiOutput("ratio"))
-                )
-              )
+              uiOutput("settingsout")
             ),
             ## display
-            bsCollapsePanel(title="Step 4. Display", value="collapseDisplay", style = "primary",
+            bsCollapsePanel(title=HTML('<font style="font-size:18px">Step 4. Display</font>'), value="collapseDisplay", style = "primary",
               column(1,bsButton("infoDisplay","",size="extra-small",style="info",icon=icon("info-circle")),offset=11),
               bsModal("infoDisplayModal",HTML('<p> <strong>Step 4. Display</strong></p>'), "infoDisplay",
                 tabsetPanel(
@@ -141,44 +124,14 @@ shinyUI(fluidPage(theme = shinytheme("spacelab"),
                   tabPanel("Decimals",uiOutput("helpdecimals")),
                   tabPanel("Labels",uiOutput("helplabel"))
                 )
-              ),    
-              conditionalPanel(
-                condition = "input.initial",
-                tabsetPanel(
-                  ## show
-                  tabPanel("Show",uiOutput("show")),
-                  ## Format display
-                  tabPanel("Format", uiOutput("format")),
-                  ## number of decimals
-                  tabPanel("Decimals", uiOutput("decimals")),
-                  ## header labels
-                  tabPanel("Labels", uiOutput("labels"))
-                )
-              )
+              ), 
+              uiOutput("displayout")
             ),
             ## save
-            bsCollapsePanel(title="Step 5. Save table", value="collapseSave", style = "primary",
+            bsCollapsePanel(title=HTML('<font style="font-size:18px">Step 5. Save table</font>'), value="collapseSave", style = "primary",
               column(1,bsButton("infoSave","",size="extra-small",style="info",icon=icon("info-circle")),offset=11),
               bsModal("infoSaveModal",HTML('<p> <strong>Step 5. Save table</strong></p>'), "infoSave", uiOutput("helpsave")),
-              conditionalPanel(
-                condition = "input.initial",  
-                selectInput("downloadtabletype", "Select format", choices = c("PDF","CSV","HTML","TXT","Word","Excel"),selectize=FALSE),
-                conditionalPanel(
-                  condition="input.downloadtabletype == 'PDF'",
-                  wellPanel(
-                    selectInput('sizepdf', 'Resize', c("tiny","scriptsize","footnotesize","small","normalsize","large","Large","LARGE","huge","Huge"),"normalsize", selectize=FALSE),
-                    h4(""),
-                    checkboxInput('landscape', 'Landscape', FALSE)
-                  )
-                ),
-                conditionalPanel(        
-                  condition="input.downloadtabletype == 'CSV'",
-                  wellPanel(
-                    radioButtons('sepcsv', 'Separator', c(Comma=',', Semicolon=';', Tab='\t'), ',')
-                  )
-                ),
-                downloadButton('actiondownloadtable', 'Download')
-              )
+              uiOutput("saveout")
             )
           )
       )
@@ -188,11 +141,12 @@ shinyUI(fluidPage(theme = shinytheme("spacelab"),
     #######  RESULTS PANEL ##########
     #################################
 
+
     column(8,
            
       div(id="outpanel",
 
-          navbarPage(title="", id="results", inverse=FALSE, 
+          navbarPage(title="", id="results", inverse=FALSE, position="static-top",
             # About
             tabPanel(value="resultsAbout",HTML('<p title="About compareGroups project">ABOUT</p>'),
               # compareGroups
@@ -223,31 +177,16 @@ shinyUI(fluidPage(theme = shinytheme("spacelab"),
               # VALUES (extended)
               tabPanel(value="resultsValues",title=HTML('<p title="Navigate thru the whole data set">Values</p>'),
                 column(1,bsButton("infoExtended","",size="extra-small",style="info",icon=icon("info-circle")),offset=11),
-                bsModal("infoExtendedModal",HTML('<p> <strong>Extended</strong></p>'), "infoExtended",uiOutput("helpvalues")),
-                conditionalPanel(
-                  condition="input.initial",
-                  bsButton("valuextoptionsaction","View",style="info"),
-                  wellPanel(id="valuextoptions",sliderInput("valueextsize", "Resize (%):", min=10, max=300, value=100, step=10))
-                ),
+                bsModal("infoExtendedModal",HTML('<p> <strong>Values</strong></p>'), "infoExtended",uiOutput("helpvalues")),
+                uiOutput("valuextoptionsout"),
                 uiOutput("valuesext")
               )
             ),
             tabPanel(value="resultsTable",title=HTML('<p title="View descriptive table" style="font-size:140%;">TABLE</p>'),
               column(1,bsButton("infoTable","",size="extra-small",style="info",icon=icon("info-circle")),offset=11),
               bsModal("infoTableModal",HTML('<p> <strong>TABLE</strong></p>'), "infoTable",uiOutput("helptable")),
-              conditionalPanel(
-                condition = "input.initial",
-                br(),
-                bsButton("tableoptionsaction", "View (hide)", style="info"),
-                wellPanel(id="tableoptions",
-                  sliderInput("htmlsizerestab", "Resize:", min=0.5, max=2, value=1, step=0.1),
-                  bsButton("tableinfo","Info"),
-                  bsModal("tableinfoModal",title="Info table",trigger="tableinfo",
-                    htmlOutput("sumtab")
-                  )
-                ),
-                uiOutput("table")
-              )        
+              uiOutput("tableoptionsout"),
+              uiOutput("table")
             ),
             tabPanel(value="resultsPlot",title=HTML('<p title="Visualize data">PLOT</p>'),
               column(1,bsButton("infoPlot","",size="extra-small",style="info",icon=icon("info-circle")),offset=11),
